<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */

if ( ! function_exists( 'regular_news_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Regular News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function regular_news_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'regular_news_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'regular_news_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Regular News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function regular_news_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'regular_news_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'regular_news_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Regular News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function regular_news_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'regular_news_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if headline section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_headline_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[headline_section_enable]' )->value() );
}

/**
 * Check if headline section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_headline_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[headline_content_type]' )->value();
	return regular_news_pro_is_headline_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if headline section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_headline_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[headline_content_type]' )->value();
	return regular_news_pro_is_headline_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if headline section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_headline_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[headline_content_type]' )->value();
	return regular_news_pro_is_headline_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[popular_content_type]' )->value();
	return regular_news_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[popular_content_type]' )->value();
	return regular_news_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[popular_content_type]' )->value();
	return regular_news_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_content_type]' )->value();
	return regular_news_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_content_type]' )->value();
	return regular_news_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_content_type]' )->value();
	return regular_news_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[cta_content_type]' )->value();
	return regular_news_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[cta_content_type]' )->value();
	return regular_news_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[cta_content_type]' )->value();
	return regular_news_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if cta section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_cta_section_content_page_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[cta_content_type]' )->value();
	return regular_news_pro_is_cta_section_enable( $control ) && ( 'post' !== $content_type );
}

/**
 * Check if recent section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[recent_section_enable]' )->value() );
}

/**
 * Check if featured_video section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_section_enable]' )->value() );
}

/**
 * Check if featured_video section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_content_type]' )->value();
	return regular_news_pro_is_featured_video_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_video section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_content_type]' )->value();
	return regular_news_pro_is_featured_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_video section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_content_type]' )->value();
	return regular_news_pro_is_featured_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_video section content type is custom.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_content_type]' )->value();
	return regular_news_pro_is_featured_video_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if featured_video section video enabled.
 *
 * @since Katha Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_featured_video_section_video_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[featured_video_content_type]' )->value();
	return regular_news_pro_is_featured_video_section_enable( $control ) && ( ! in_array( $content_type, array( 'category' ) ) );
}


/**
 * Check if blog section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[blog_content_type]' )->value();
	return regular_news_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[blog_content_type]' )->value();
	return regular_news_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[blog_content_type]' )->value();
	return regular_news_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[blog_content_type]' )->value();
	return regular_news_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if must_read section is enabled.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_must_read_section_enable( $control ) {
	return ( $control->manager->get_setting( 'regular_news_pro_theme_options[must_read_section_enable]' )->value() );
}

/**
 * Check if must_read section content type is category.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_must_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[must_read_content_type]' )->value();
	return regular_news_pro_is_must_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must_read section content type is page.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_must_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[must_read_content_type]' )->value();
	return regular_news_pro_is_must_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must_read section content type is post.
 *
 * @since Regular News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function regular_news_pro_is_must_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'regular_news_pro_theme_options[must_read_content_type]' )->value();
	return regular_news_pro_is_must_read_section_enable( $control ) && ( 'post' == $content_type );
}



